@@ -265,6 +265,8 @@ class binary_eda_plot:
                       ax=ax
                      )
 
+        self.label_bar(ax, len(self.data))
+
         self.format_ax(ax)
         
         plt.ticklabel_format(style='plain', axis='y')
@@ -273,9 +275,7 @@ class binary_eda_plot:
         
         plt.xlabel('')
         
-        self.label_bar(ax, len(self.data))
-        
-        plt.legend(loc='upper right')
+        plt.legend(loc='upper right', frameon=False)
         
     def create_bins(self, col):
         
